@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009-2014 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2009-2016,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,8 +52,8 @@
 /**                                 to   : 12 sep 2007     **/
 /**                # Version 5.1  : from : 05 jun 2009     **/
 /**                                 to   : 13 feb 2011     **/
-/**                # Version 6.0  : from : 14 fev 2011     **/
-/**                                 to     19 aug 2014     **/
+/**                # Version 6.0  : from : 14 feb 2011     **/
+/**                                 to     05 jun 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -71,6 +71,7 @@
 #include "arch_cmpltw.h"
 #include "arch_hcub.h"
 #include "arch_mesh.h"
+#include "arch_sub.h"
 #include "arch_tleaf.h"
 #include "arch_torus.h"
 #include "arch_vcmplt.h"
@@ -93,7 +94,7 @@
 +*/
 
 SCOTCH_Arch *
-SCOTCH_archAlloc ()
+SCOTCH_archAlloc (void)
 {
   return ((SCOTCH_Arch *) memAlloc (sizeof (SCOTCH_Arch)));
 }
@@ -111,11 +112,11 @@ SCOTCH_archInit (
 SCOTCH_Arch * const         archptr)
 {
   if (sizeof (SCOTCH_Num) != sizeof (Anum)) {
-    errorPrint ("SCOTCH_archInit: internal error (1)");
+    errorPrint (STRINGIFY (SCOTCH_archInit) ": internal error (1)");
     return     (1);
   }
   if (sizeof (SCOTCH_Arch) < sizeof (Arch)) {
-    errorPrint ("SCOTCH_archInit: internal error (2)");
+    errorPrint (STRINGIFY (SCOTCH_archInit) ": internal error (2)");
     return     (1);
   }
 
@@ -222,22 +223,22 @@ const SCOTCH_Arch * const   archptr)
 int
 SCOTCH_archCmplt (
 SCOTCH_Arch * const         archptr,
-const SCOTCH_Num            numnbr)
+const SCOTCH_Num            termnbr)
 {
   Arch *              tgtarchptr;
   ArchCmplt *         tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archCmplt: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archCmplt) ": internal error");
     return     (1);
   }
 
   tgtarchptr    = (Arch *) archptr;
   tgtarchdatptr = (ArchCmplt *) (void *) (&tgtarchptr->data);
 
-  tgtarchptr->class     = archClass ("cmplt");
-  tgtarchptr->flagval   = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->numnbr = (Anum) numnbr;
+  tgtarchptr->class      = archClass ("cmplt");
+  tgtarchptr->flagval    = tgtarchptr->class->flagval; /* Copy architecture flag */
+  tgtarchdatptr->termnbr = (Anum) termnbr;
 
   return (0);
 }
@@ -255,7 +256,7 @@ const SCOTCH_Num * const    velotab)
   Arch *              tgtarchptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archCmpltw: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archCmpltw) ": internal error");
     return     (1);
   }
 
@@ -273,22 +274,22 @@ const SCOTCH_Num * const    velotab)
 int
 SCOTCH_archHcub (
 SCOTCH_Arch * const         archptr,
-const SCOTCH_Num            dimmax)               /*+ Number of dimensions +*/
+const SCOTCH_Num            dimnnbr)              /*+ Number of dimensions +*/
 {
   Arch *              tgtarchptr;
   ArchHcub *          tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archHcub: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archHcub) ": internal error");
     return     (1);
   }
 
   tgtarchptr    = (Arch *) archptr;
   tgtarchdatptr = (ArchHcub *) (void *) (&tgtarchptr->data);
 
-  tgtarchptr->class     = archClass ("hcub");
-  tgtarchptr->flagval   = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->dimmax = (Anum) dimmax;
+  tgtarchptr->class      = archClass ("hcub");
+  tgtarchptr->flagval    = tgtarchptr->class->flagval; /* Copy architecture flag */
+  tgtarchdatptr->dimnnbr = (Anum) dimnnbr;
 
   return (0);
 }
@@ -307,7 +308,7 @@ const SCOTCH_Num            dimyval)
   ArchMesh2 *         tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archMesh2: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archMesh2) ": internal error");
     return     (1);
   }
 
@@ -316,8 +317,9 @@ const SCOTCH_Num            dimyval)
 
   tgtarchptr->class   = archClass ("mesh2D");
   tgtarchptr->flagval = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->c[0] = (Anum) dimxval;
-  tgtarchdatptr->c[1] = (Anum) dimyval;
+  tgtarchdatptr->dimnnbr = 2;
+  tgtarchdatptr->c[0]    = (Anum) dimxval;
+  tgtarchdatptr->c[1]    = (Anum) dimyval;
 
   return (0);
 }
@@ -337,7 +339,7 @@ const SCOTCH_Num            dimzval)
   ArchMesh3 *         tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archMesh3: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archMesh3) ": internal error");
     return     (1);
   }
 
@@ -346,9 +348,10 @@ const SCOTCH_Num            dimzval)
 
   tgtarchptr->class   = archClass ("mesh3D");
   tgtarchptr->flagval = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->c[0] = (Anum) dimxval;
-  tgtarchdatptr->c[1] = (Anum) dimyval;
-  tgtarchdatptr->c[2] = (Anum) dimzval;
+  tgtarchdatptr->dimnnbr = 3;
+  tgtarchdatptr->c[0]    = (Anum) dimxval;
+  tgtarchdatptr->c[1]    = (Anum) dimyval;
+  tgtarchdatptr->c[2]    = (Anum) dimzval;
 
   return (0);
 }
@@ -357,6 +360,67 @@ const SCOTCH_Num            dimzval)
 **
 */
 
+int
+SCOTCH_archMeshX (
+SCOTCH_Arch * const         archptr,
+const SCOTCH_Num            dimnnbr,              /*+ Number of dimensions in architecture +*/
+const SCOTCH_Num * const    dimntab)              /*+ Array of dimensions                  +*/
+{
+  Arch *              tgtarchptr;
+  ArchMeshX *         tgtarchdatptr;
+
+  if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
+    errorPrint (STRINGIFY (SCOTCH_archMeshX) ": internal error");
+    return     (1);
+  }
+  if (dimnnbr > ARCHMESHDIMNMAX) {
+    errorPrint (STRINGIFY (SCOTCH_archMeshX) ": too many dimensions");
+    return     (1);
+  }
+
+  tgtarchptr    = (Arch *) archptr;
+  tgtarchdatptr = (ArchMeshX *) (void *) (&tgtarchptr->data);
+
+  tgtarchptr->class      = archClass ("meshXD");
+  tgtarchptr->flagval    = tgtarchptr->class->flagval; /* Copy architecture flag */
+  tgtarchdatptr->dimnnbr = dimnnbr;
+  memCpy (tgtarchdatptr->c, dimntab, dimnnbr * sizeof (SCOTCH_Num)); /* Copy dimension array */
+
+  return (0);
+}
+
+/*
+**
+*/
+
+int
+SCOTCH_archSub (
+SCOTCH_Arch * const         subarchptr,
+SCOTCH_Arch * const         orgarchptr,
+const SCOTCH_Num            vnumnbr,              /*+ Number of dimensions +*/
+const SCOTCH_Num * const    vnumtab)
+{
+  Arch *              tgtarchptr;
+  ArchSub *           tgtarchdatptr;
+
+  if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
+    errorPrint (STRINGIFY (SCOTCH_archSub) ": internal error");
+    return     (2);
+  }
+
+  tgtarchptr    = (Arch *) subarchptr;
+  tgtarchdatptr = (ArchSub *) (void *) (&tgtarchptr->data);
+
+  tgtarchptr->class   = archClass ("sub");
+  tgtarchptr->flagval = tgtarchptr->class->flagval; /* Copy architecture flag */
+
+  return (archSubArchBuild (tgtarchdatptr, (Arch *) orgarchptr, (Gnum) vnumnbr, (Gnum *) vnumtab));
+}
+
+/*
+**
+*/
+
 int
 SCOTCH_archTleaf (
 SCOTCH_Arch * const         archptr,
@@ -370,7 +434,7 @@ const SCOTCH_Num * const    linktab)              /*+ Link cost array, by increa
   ArchTleaf *         tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archTleaf: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archTleaf) ": internal error");
     return     (1);
   }
 
@@ -380,7 +444,7 @@ const SCOTCH_Num * const    linktab)              /*+ Link cost array, by increa
   tgtarchptr->flagval = tgtarchptr->class->flagval; /* Copy architecture flag */
 
   if ((tgtarchdatptr->sizetab = memAlloc ((levlnbr * 2 + 1) * sizeof (Anum))) == NULL) { /* TRICK: One more slot for linktab[-1] */
-    errorPrint ("SCOTCH_archTleaf: out of memory");
+    errorPrint (STRINGIFY (SCOTCH_archTleaf) ": out of memory");
     return     (1);
   }
   tgtarchdatptr->levlnbr     = (Anum) levlnbr;
@@ -411,9 +475,7 @@ const SCOTCH_Num * const    linktab,              /*+ Link cost array, by increa
 const SCOTCH_Num            permnbr,              /*+ Number of permutation indices               +*/
 const SCOTCH_Num * const    permtab)              /*+ Permutation array                           +*/
 {
-/*  Anum                levlnum;*/
   Anum                permnum;
-/*  Anum                sizeval;*/
   Arch *              tgtarchptr;
   ArchTleaf *         tgtarchdatptr;
 
@@ -424,7 +486,7 @@ const SCOTCH_Num * const    permtab)              /*+ Permutation array
   tgtarchptr->class = archClass ("ltleaf");       /* Override class */
 
   if ((tgtarchdatptr->permtab = memAlloc (permnbr * 2 * sizeof (Anum))) == NULL) { /* TRICK: space for peritab too */
-    errorPrint ("SCOTCH_archLtleaf: out of memory");
+    errorPrint (STRINGIFY (SCOTCH_archLtleaf) ": out of memory");
     return     (1);
   }
   tgtarchdatptr->permnbr = (Anum) permnbr;
@@ -452,18 +514,18 @@ const SCOTCH_Num            dimyval)
   ArchTorusX *        tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archTorus2: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archTorus2) ": internal error");
     return     (1);
   }
 
   tgtarchptr    = (Arch *) archptr;
   tgtarchdatptr = (ArchTorusX *) (void *) (&tgtarchptr->data);
 
-  tgtarchptr->class     = archClass ("torus2D");
-  tgtarchptr->flagval   = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->dimmax = 2;
-  tgtarchdatptr->c[0]   = (Anum) dimxval;
-  tgtarchdatptr->c[1]   = (Anum) dimyval;
+  tgtarchptr->class      = archClass ("torus2D");
+  tgtarchptr->flagval    = tgtarchptr->class->flagval; /* Copy architecture flag */
+  tgtarchdatptr->dimnnbr = 2;
+  tgtarchdatptr->c[0]    = (Anum) dimxval;
+  tgtarchdatptr->c[1]    = (Anum) dimyval;
 
   return (0);
 }
@@ -483,19 +545,19 @@ const SCOTCH_Num            dimzval)
   ArchTorusX *        tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archTorus3: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archTorus3) ": internal error");
     return     (1);
   }
 
   tgtarchptr    = (Arch *) archptr;
   tgtarchdatptr = (ArchTorusX *) (void *) (&tgtarchptr->data);
 
-  tgtarchptr->class     = archClass ("torus3D");
-  tgtarchptr->flagval   = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->dimmax = 3;
-  tgtarchdatptr->c[0]   = (Anum) dimxval;
-  tgtarchdatptr->c[1]   = (Anum) dimyval;
-  tgtarchdatptr->c[2]   = (Anum) dimzval;
+  tgtarchptr->class      = archClass ("torus3D");
+  tgtarchptr->flagval    = tgtarchptr->class->flagval; /* Copy architecture flag */
+  tgtarchdatptr->dimnnbr = 3;
+  tgtarchdatptr->c[0]    = (Anum) dimxval;
+  tgtarchdatptr->c[1]    = (Anum) dimyval;
+  tgtarchdatptr->c[2]    = (Anum) dimzval;
 
   return (0);
 }
@@ -507,28 +569,28 @@ const SCOTCH_Num            dimzval)
 int
 SCOTCH_archTorusX (
 SCOTCH_Arch * const         archptr,
-const SCOTCH_Num            dimnbr,               /*+ Number of dimensions in architecture +*/
-const SCOTCH_Num * const    dimtab)               /*+ Array of dimensions                  +*/
+const SCOTCH_Num            dimnnbr,              /*+ Number of dimensions in architecture +*/
+const SCOTCH_Num * const    dimntab)              /*+ Array of dimensions                  +*/
 {
   Arch *              tgtarchptr;
   ArchTorusX *        tgtarchdatptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archTorusX: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archTorusX) ": internal error");
     return     (1);
   }
-  if (dimnbr > ARCHTORUSDIMMAX) {
-    errorPrint ("SCOTCH_archTorusX: too many dimensions");
+  if (dimnnbr > ARCHMESHDIMNMAX) {
+    errorPrint (STRINGIFY (SCOTCH_archTorusX) ": too many dimensions");
     return     (1);
   }
 
   tgtarchptr    = (Arch *) archptr;
   tgtarchdatptr = (ArchTorusX *) (void *) (&tgtarchptr->data);
 
-  tgtarchptr->class     = archClass ("torusXD");
-  tgtarchptr->flagval   = tgtarchptr->class->flagval; /* Copy architecture flag */
-  tgtarchdatptr->dimmax = dimnbr;
-  memCpy (tgtarchdatptr->c, dimtab, dimnbr * sizeof (SCOTCH_Num)); /* Copy dimension array */
+  tgtarchptr->class      = archClass ("torusXD");
+  tgtarchptr->flagval    = tgtarchptr->class->flagval; /* Copy architecture flag */
+  tgtarchdatptr->dimnnbr = dimnnbr;
+  memCpy (tgtarchdatptr->c, dimntab, dimnnbr * sizeof (SCOTCH_Num)); /* Copy dimension array */
 
   return (0);
 }
@@ -544,7 +606,7 @@ SCOTCH_Arch * const         archptr)
   Arch *              tgtarchptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archVcmplt: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archVcmplt) ": internal error");
     return     (1);
   }
 
@@ -567,7 +629,7 @@ SCOTCH_Arch * const         archptr)
   Arch *              tgtarchptr;
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_archVhcub: internal error");
+    errorPrint (STRINGIFY (SCOTCH_archVhcub) ": internal error");
     return     (1);
   }
 
