@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2010,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,6 +43,8 @@
 /**                                 to     11 may 2004     **/
 /**                # Version 5.1  : from : 17 nov 2010     **/
 /**                                 to     17 nov 2010     **/
+/**                # Version 6.0  : from : 25 apr 2018     **/
+/**                                 to     25 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -74,7 +76,7 @@
 +*/
 
 SCOTCH_Mesh *
-SCOTCH_meshAlloc ()
+SCOTCH_meshAlloc (void)
 {
   return ((SCOTCH_Mesh *) memAlloc (sizeof (SCOTCH_Mesh)));
 }
@@ -92,11 +94,11 @@ SCOTCH_meshInit (
 SCOTCH_Mesh * const         meshptr)
 {
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_meshInit: internal error (1)");
+    errorPrint (STRINGIFY (SCOTCH_meshInit) ": internal error (1)");
     return     (1);
   }
   if (sizeof (SCOTCH_Mesh) < sizeof (Mesh)) {
-    errorPrint ("SCOTCH_meshInit: internal error (2)");
+    errorPrint (STRINGIFY (SCOTCH_meshInit) ": internal error (2)");
     return     (1);
   }
 
@@ -134,7 +136,7 @@ FILE * const                stream,
 const SCOTCH_Num            baseval)
 {
   if ((baseval < -1) || (baseval > 1)) {
-    errorPrint ("SCOTCH_meshLoad: invalid base parameter");
+    errorPrint (STRINGIFY (SCOTCH_meshLoad) ": invalid base parameter");
     return     (1);
   }
 
@@ -187,19 +189,19 @@ const SCOTCH_Num * const    edgetab)              /* Edge array [edgenbr]
 
 #ifdef SCOTCH_DEBUG_LIBRARY1
   if (sizeof (SCOTCH_Mesh) < sizeof (Mesh)) {
-    errorPrint ("SCOTCH_meshBuild: internal error (1)");
+    errorPrint (STRINGIFY (SCOTCH_meshBuild) ": internal error (1)");
     return     (1);
   }
 #endif /* SCOTCH_DEBUG_LIBRARY1 */
   if ((velmbas < 0) ||
       (vnodbas < 0) ||
       ((velmbas > 1) && (vnodbas > 1))) {
-    errorPrint ("SCOTCH_meshBuild: invalid base parameters");
+    errorPrint (STRINGIFY (SCOTCH_meshBuild) ": invalid base parameters");
     return     (1);
   }
   if (((velmbas + velmnbr) != vnodbas) &&
       ((vnodbas + vnodnbr) != velmbas)) {
-    errorPrint ("SCOTCH_meshBuild: invalid element or node range");
+    errorPrint (STRINGIFY (SCOTCH_meshBuild) ": invalid element or node range");
     return     (1);
   }
 
@@ -269,7 +271,7 @@ const SCOTCH_Num * const    edgetab)              /* Edge array [edgenbr]
 
 #ifdef SCOTCH_DEBUG_LIBRARY1
   if (meshCheck (srcmeshptr) != 0) {
-    errorPrint ("SCOTCH_meshBuild: internal error (2)");
+    errorPrint (STRINGIFY (SCOTCH_meshBuild) ": internal error (2)");
     return     (1);
   }
 #endif /* SCOTCH_DEBUG_LIBRARY1 */
